@@ -10,7 +10,7 @@ package Algorithm::AM;
 use strict;
 use warnings;
 # ABSTRACT: Classify data with Analogical Modeling
-our $VERSION = '3.01'; # VERSION
+our $VERSION = '3.02'; # VERSION
 use feature 'state';
 use Carp;
 our @CARP_NOT = qw(Algorithm::AM);
@@ -63,9 +63,9 @@ sub _initialize {
     my ($self) = @_;
 
     my $train = $self->training_set;
-    # compute activeVars here so that lattice space can be allocated in the
+    # compute active_feats here so that lattice space can be allocated in the
     # _initialize method
-    $self->{activeVars} = _compute_lattice_sizes($train->cardinality);
+    $self->{active_feats} = _compute_lattice_sizes($train->cardinality);
 
     # sum is intitialized to a list of zeros
     @{$self->{sum}} = (0.0) x ($train->num_classes + 1);
@@ -73,8 +73,6 @@ sub _initialize {
     # preemptively allocate memory
     # TODO: not sure what this does
     @{$self->{itemcontextchain}} = (0) x $train->size;
-    # maps data indices to context labels
-    @{$self->{datatocontext}} = ( pack "S!4", 0, 0, 0, 0 ) x $train->size;
 
     $self->{$_} = {} for (
         qw(
@@ -91,7 +89,7 @@ sub _initialize {
     # must not be increasing the reference count
     $self->{save_this} = $train->_data_classes;
     $self->_xs_initialize(
-        $self->{activeVars},
+        $self->{active_feats},
         $self->{save_this},
         $self->{itemcontextchain},
         $self->{itemcontextchainhead},
@@ -114,28 +112,28 @@ sub classify {
                 $test_item->cardinality . ')';
     }
 
-    # num_variables is the number of active variables; if we
-    # exclude nulls, then we need to minus the number of '=' found in
-    # this test item; otherwise, it's just the number of columns in a
-    # single item vector
-    my $num_variables = $training_set->cardinality;
+    # num_feats is the number of features to be used in classification;
+    # if we exclude nulls, then we need to minus the number of '='
+    # found in this test item; otherwise, it's just the number of
+    # columns in a single item vector
+    my $num_feats = $training_set->cardinality;
 
     if($self->exclude_nulls){
-        $num_variables -= grep {$_ eq ''} @{
+        $num_feats -= grep {$_ eq ''} @{
             $test_item->features };
     }
 
-    # recalculate the lattice sizes with new number of active variables;
-    # must edit activeVars instead of assigning it a new arrayref because
+    # recalculate the lattice sizes with new number of active features;
+    # must edit active_feats instead of assigning it a new arrayref because
     # the XS code only has the existing arrayref and will not be given
-    # a new one. This must be done for every test item because activeVars
+    # a new one. This must be done for every test item because active_feats
     # is a global that could have been edited during classification of the
     # last test item.
-    # TODO: pass activeVars into fill_and_count instead of doing this
+    # TODO: pass active_feats into fill_and_count instead of doing this
     {
-        my $lattice_sizes = _compute_lattice_sizes($num_variables);
+        my $lattice_sizes = _compute_lattice_sizes($num_feats);
         for(0 .. $#$lattice_sizes){
-            $self->{activeVars}->[$_] = $lattice_sizes->[$_];
+            $self->{active_feats}->[$_] = $lattice_sizes->[$_];
         }
     }
 ##  $activeContexts = 1 << $activeVar;
@@ -143,7 +141,7 @@ sub classify {
     my $nullcontext = pack "b64", '0' x 64;
 
     my $given_excluded = 0;
-    my $testindata   = 0;
+    my $test_in_training   = 0;
 
     # initialize classification-related variables
     # it is important to dereference rather than just
@@ -156,7 +154,6 @@ sub classify {
     %{$self->{context_to_class}}      = ();
     %{$self->{pointers}}                = ();
     %{$self->{gang}}                    = ();
-    @{$self->{datatocontext}}           = ();
     @{$self->{itemcontextchain}}        = ();
     # big ints are used in AM.xs; these consist of an
     # array of 8 unsigned longs
@@ -166,27 +163,26 @@ sub classify {
 
     # calculate context labels and associated structures for
     # the entire data set
-    for my $data_index ( 0 .. $training_set->size - 1 ) {
+    for my $index ( 0 .. $training_set->size - 1 ) {
         my $context = _context_label(
             # Note: this must be copied to prevent infinite loop;
             # see todo note for _context_label
-            [@{$self->{activeVars}}],
-            $training_set->get_item($data_index)->features,
+            [@{$self->{active_feats}}],
+            $training_set->get_item($index)->features,
             $test_item->features,
             $self->exclude_nulls
         );
         $self->{contextsize}->{$context}++;
-        $self->{datatocontext}->[$data_index] = $context;
         # TODO: explain itemcontextchain and itemcontextchainhead
-        $self->{itemcontextchain}->[$data_index] =
+        $self->{itemcontextchain}->[$index] =
             $self->{itemcontextchainhead}->{$context};
-        $self->{itemcontextchainhead}->{$context} = $data_index;
+        $self->{itemcontextchainhead}->{$context} = $index;
 
         # store the class for the subcontext; if there
         # is already a different class for this subcontext,
         # then store 0, signifying heterogeneity.
         my $class = $training_set->_index_for_class(
-            $training_set->get_item($data_index)->class);
+            $training_set->get_item($index)->class);
         if ( defined $self->{context_to_class}->{$context} ) {
             $self->{context_to_class}->{$context} = 0
               if $self->{context_to_class}->{$context} != $class;
@@ -196,10 +192,11 @@ sub classify {
         }
     }
     # $nullcontext is all 0's, which is a context label for
-    # a data item that exactly matches the test item. Take note
-    # of the item, and exclude it if required.
+    # a training item that exactly matches the test item. Exclude
+    # the item if required, and set a flag that the test item was
+    # found in the training set.
     if ( exists $self->{context_to_class}->{$nullcontext} ) {
-        $testindata = 1;
+        $test_in_training = 1;
         if($self->exclude_given){
            delete $self->{context_to_class}->{$nullcontext};
            $given_excluded = 1;
@@ -209,12 +206,12 @@ sub classify {
     # info.
     my $result = Algorithm::AM::Result->new(
         given_excluded => $given_excluded,
-        cardinality => $num_variables,
+        cardinality => $num_feats,
         exclude_nulls => $self->exclude_nulls,
         count_method => $self->linear ? 'linear' : 'squared',
         training_set => $training_set,
         test_item => $test_item,
-        test_in_data => $testindata,
+        test_in_train => $test_in_training,
     );
 
     $log->debug(${$result->config_info})
@@ -227,7 +224,7 @@ sub classify {
     unless ($self->{pointers}->{'grandtotal'}) {
         #TODO: is this tested yet?
         if($log->is_warn){
-            $log->warn('No data items considered. ' .
+            $log->warn('No training items considered. ' .
                 'No prediction possible.');
         }
         return;
@@ -242,59 +239,59 @@ sub classify {
         $self->{itemcontextchain},
         $self->{context_to_class},
         $self->{gang},
-        $self->{activeVars},
+        $self->{active_feats},
         $self->{contextsize}
     );
     return $result;
 }
 
-# since we split the lattice in four, we have to decide which variables
-# go where. Given the number of variables being used, return an arrayref
-# containing the number of variables to be used in each of the the four
+# since we split the lattice in four, we have to decide which features
+# go where. Given the number of features being used, return an arrayref
+# containing the number of features to be used in each of the the four
 # lattices.
 sub _compute_lattice_sizes {
     my ($num_feats) = @_;
 
     use integer;
-    my @active_vars;
+    my @active_feats;
     my $half = $num_feats / 2;
-    $active_vars[0] = $half / 2;
-    $active_vars[1] = $half - $active_vars[0];
+    $active_feats[0] = $half / 2;
+    $active_feats[1] = $half - $active_feats[0];
     $half         = $num_feats - $half;
-    $active_vars[2] = $half / 2;
-    $active_vars[3] = $half - $active_vars[2];
-    return \@active_vars;
+    $active_feats[2] = $half / 2;
+    $active_feats[3] = $half - $active_feats[2];
+    return \@active_feats;
 }
 
-# Create binary context labels for a data item
-# by comparing it with a test item. Each data item
+# Create binary context labels for a training item
+# by comparing it with a test item. Each training item
 # needs one binary label for each sublattice (of which
 # there are currently four), but this is packed into a
 # single scalar representing an array of 4 shorts (this
 # format is used in the XS side).
 
-# TODO: we have to copy activeVars out of $self in order to
+# TODO: we have to copy active_feats out of $self in order to
 # iterate it. Otherwise it goes on forever. Why?
 sub _context_label {
     # inputs:
-    # number of active variables in each lattice,
+    # number of active features in each lattice,
     # training item features, test item features,
     # and boolean indicating if nulls should be excluded
-    my ($active_vars, $train_feats, $test_feats, $skip_nulls) = @_;
+    my ($active_feats, $train_feats, $test_feats, $skip_nulls) = @_;
 
-    # variable index
+    # feature index
     my $index        = 0;
     # the binary context labels for each separate lattice
     my @context_list    = ();
 
-    for my $a (@$active_vars) {
+    for my $a (@$active_feats) {
         # binary context label for a single sublattice
         my $context = 0;
-        # loop through all variables in the sublattice
-        # assign 0 if variables match, 1 if they do not
+        # loop through all features in the sublattice
+        # assign 0 if features match, 1 if they do not
         for ( ; $a ; --$a ) {
 
-            # skip null variables if indicated
+            # skip null features if indicated
             if($skip_nulls){
                 ++$index while $test_feats->[$index] eq '';
             }
@@ -329,7 +326,7 @@ Algorithm::AM - Classify data with Analogical Modeling
 
 =head1 VERSION
 
-version 3.01
+version 3.02
 
 =head1 SYNOPSIS
 
@@ -445,7 +442,7 @@ while the parsing, printing, and statistical routines remained in C;
 this was accomplished by embedding a Perl interpreter into the C code.
 
 In 2004, the algorithm was again rewritten, this time in order to
-handle more variables and large data sets. The algorithm breaks the
+handle more features and large data sets. The algorithm breaks the
 supracontextual lattice into the direct product of four smaller ones,
 which the algorithm manipulates individually before recombining.
 These lattices can be manipulated in parallel when using the right
