@@ -16,7 +16,7 @@ use Exporter::Easy (
     OK => ['dataset_from_file']
 );
 # ABSTRACT: Manage data used by Algorithm::AM
-our $VERSION = '3.01'; # VERSION;
+our $VERSION = '3.02'; # VERSION;
 
 sub new {
     my ($class, %opts) = @_;
@@ -30,10 +30,9 @@ sub new {
     return $self;
 }
 
-# check the project path and the options for validity
-# Return an option hash to initialize $self with, containing the
-# project path object, number of variables, and field_sep and var_sep,
-# which are used to parse data lines
+# check the options for validity
+# Return an option hash to initialize $self with
+# For now only 'cardinality' is allowed/required.
 sub _check_opts {
     my (%opts) = @_;
 
@@ -99,7 +98,7 @@ sub add_item {
 
     if($self->cardinality != $item->cardinality){
         croak 'Expected ' . $self->cardinality .
-            ' variables, but found ' . (scalar $item->cardinality) .
+            ' features, but found ' . (scalar $item->cardinality) .
             ' in ' . (join ' ', @{$item->features}) .
             ' (' . $item->comment . ')';
     }
@@ -108,12 +107,12 @@ sub add_item {
         $self->_update_class_vars($item->class);
     }
 
-    # store the new data item
+    # store the new item
     push @{$self->{items}}, $item;
     return;
 }
 
-# keep track of classes; needs updating for every data/test item.
+# keep track of classes; needs updating for new item
 sub _update_class_vars {
     my ($self, $class) = @_;
 
@@ -180,14 +179,14 @@ sub dataset_from_file {## no critic (RequireArgUnpacking)
 
     my ($field_sep, $feature_sep);
     if($format eq 'commas'){
-        # class/data/comment separated by a comma
+        # class/features/comment separated by a comma
         $field_sep   = qr{\s*,\s*};
-        # variables separated by space
+        # features separated by space
         $feature_sep = qr{\s+};
     }elsif($format eq 'nocommas'){
-        # class/data/comment separated by space
+        # class/features/comment separated by space
         $field_sep   = qr{\s+};
-        # no seps for variables; each is a single character
+        # no seps for features; each is a single character
         $feature_sep = qr{};
     }else{
         croak "Unknown value $format for format parameter " .
@@ -212,11 +211,12 @@ sub dataset_from_file {## no critic (RequireArgUnpacking)
     return $dataset;
 }
 
-# return a sub that returns one data vector per call from the given FH,
-# and returns undef once the data file is done being read. Throws errors
+# return a sub that returns one Item per call from the given FH,
+# and returns undef once the file is done being read. Throws errors
 # on bad file contents.
 # Input is file (Path::Tiny), string representing unknown class,
-# field separator (class, features, comment) and feature separator
+# string representing null feature, field separator (class,
+# features, comment) and feature separator
 sub _read_data_sub {
     my ($data_file, $unknown, $null,
         $field_sep, $feature_sep) = @_;
@@ -245,7 +245,7 @@ sub _read_data_sub {
         }
 
         my @data_vars = split /$feature_sep/, $feats;
-        # set unknown variables to ''
+        # set null features to ''
         @data_vars = map {$_ eq $null ? '' : $_} @data_vars;
 
         return Algorithm::AM::DataSet::Item->new(
@@ -268,7 +268,7 @@ Algorithm::AM::DataSet - Manage data used by Algorithm::AM
 
 =head1 VERSION
 
-version 3.01
+version 3.02
 
 =head1 SYNOPSIS
 
@@ -298,7 +298,8 @@ a feature vector, and also optionally a class label and a comment
 
 =head2 C<cardinality>
 
-Returns the number of features contained in a single data vector.
+Returns the number of features contained in the feature vector of a
+single item.
 
 =head2 C<size>
 
